require './test/test_helper'
require 'yaml'

describe Divy::DivGenerator do

  before do
    @test_div = Divy::DivGenerator.new
    @html_results = YAML.load(File.open('test/lib/divy/html_examples.yml'))
  end

  describe '#default_stylez' do
    it 'should return the common default styles given no arguments' do
      @test_div.default_stylez.must_equal 'position: absolute;'
    end

    it 'should return default styles given show_grid as false' do
      options = {show_grid: false}
      @test_div.default_stylez(options).must_equal 'position: absolute;'
    end

    it 'should return default grid colors if given show_grid as true' do
      options = {show_grid: true}
      style = 'position: absolute; border-style:solid; border-color:#000000;'
      @test_div.default_stylez(options). must_equal style
    end

    it 'should return the input color as boredr color if show_grid true and color provided' do
      options = {show_grid: true, grid_color: '#00FFFF'}
      style = 'position: absolute; border-style:solid; border-color:#00FFFF;'
      @test_div.default_stylez(options).must_equal style
    end
  end

  describe '#scaled_percentage' do
    it 'should return the percentage of a single unit based on number of units' do
      @test_div.scaled_percentage(7).must_equal 14.285714285714286
    end

    it 'should respond correctly if given a string number' do
      @test_div.scaled_percentage('7').must_equal 14.285714285714286
    end
  end

  describe '#scaled_value' do
    it 'should return the percentage of height based on y unit location' do
      @test_div.scaled_value(10, 3).must_equal 30
    end

    it 'should respond correctly for a float result' do
      @test_div.scaled_value(7, 3).must_equal 42.85714285714286
    end

    it 'should respond currently given strign numbers' do
      @test_div.scaled_value('7', 3).must_equal 42.85714285714286
      @test_div.scaled_value(7, '3').must_equal 42.85714285714286
    end
  end

  describe '#divy_box_stylez' do
    it 'should return the style parameters for a divybox' do
      style = 'bottom: 20.0%; left: 10.0%; width: 10.0%; height: 10.0%; position: absolute;'
      @test_div.divy_box_stylez(1, 2, [10, 10]).must_equal style
    end

    it 'should return colors if borders and colors if correct options are passed' do
      options = {show_grid: true, grid_color: '#00FFFF'}
      style = 'bottom: 20.0%; left: 10.0%; width: 10.0%; height: 10.0%; position: absolute; border-style:solid; border-color:#00FFFF;'
      @test_div.divy_box_stylez(1, 2, [10, 10], nil, options).must_equal style
    end

    it 'should return modified content styles if content size is passed' do
      options = {show_grid: true, grid_color: '#00FFFF'}
      style = 'bottom: 15.0%; left: 5.0%; width: 20.0%; height: 20.0%; position: absolute;'
      @test_div.divy_box_stylez(1, 2, [10, 10], [2, 2], options).must_equal style
    end
  end

  describe '#divy_box' do
    it 'should return a default box and location gven no inputs' do
      div_content = "<div class=\"divybox\" style=\"bottom: 0.0%; left: 0.0%; width: 10.0%; height: 10.0%; position: absolute;\"></div>\n"
      @test_div.divy_box.must_equal div_content
    end

    it 'should add content to the div if content is passed' do
      div_content = "<div class=\"divybox\" style=\"bottom: 0.0%; left: 0.0%; width: 10.0%; height: 10.0%; position: absolute;\">1</div>\n"
      @test_div.divy_box(0, 0, [10, 10], 1).must_equal div_content
    end
  end

  describe '#divy_container' do
    it 'should wrap the given content in a divycontainer div with %' do
      div_content = "<div class=\"divycontainer\" style=\"position:relative; width: 100%; height: 100%;\">\ntest content</div>\n"
      @test_div.divy_container(['100%', '100%'], 'test content').must_equal div_content
    end

    it 'should wrap the given content in a divycontainer div with as px' do
      div_content = "<div class=\"divycontainer\" style=\"position:relative; width: 100px; height: 100px;\">\ntest content</div>\n"
      @test_div.divy_container([100, 100], 'test content').must_equal div_content
    end

  end

  describe '#divy_content' do
    it 'should return all content for the given content array' do
      content = [
        {type: :html, value: 'coolhtmlstuff', location: [1, 3], size: [1, 1]},
        {type: :image, value: 'someimagepath', location: [1, 5], size: [1, 1]},
        {type: :none, value: 'gonnaignorethisanyways', location: [1, 7], size: [1, 1]}
      ]
      @test_div.divy_content([10, 10], content).must_equal @html_results[3]
    end

    it 'should include options in teh divy box if they are passed' do
      options = {show_grid: true, grid_color: '#00FFFF'}
      content = [
        {type: :html, value: 'coolhtmlstuff', location: [1, 3], size: [1, 1]},
        {type: :image, value: 'someimagepath', location: [1, 5], size: [1, 1]},
        {type: :none, value: 'gonnaignorethisanyways', location: [1, 7], size: [1, 1]}
      ]
      @test_div.divy_content([10, 10], content, options).must_equal @html_results[2]
    end
  end

  describe '#grid_html' do
    it 'should return each square of the div grid with no options' do
      @test_div.grid_html([3, 3]).must_equal @html_results[1]
    end
  end


end
